==> owncloud-10.0.7.tgz: owncloud/lib/l10n/ca.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "No es pot escriure a la carpeta \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Això normalment es pot solucionar donant al servidor web permís d'escriptura a la carpeta de configuració",
    "See %s" : "Comproveu %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Això normalment es pot solucionar donant a %s permís d'escriptura a la carpeta de configuració %s",
    "Sample configuration detected" : "Configuració d'exemple detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S'ha detectat que la configuració d'exemple ha estat copiada. Això no està suportat, i podria corrompre la vostra instalació. Siusplau, llegiu la documentació abans de realitzar canvis a config.php",
    "PHP %s or higher is required." : "Es requereix PHP %s o superior.",
    "Unknown filetype" : "Tipus de fitxer desconegut",
    "Invalid image" : "Imatge no vàlida",
    "today" : "avui",
    "yesterday" : "ahir",
    "last month" : "el mes passat",
    "_%n month ago_::_%n months ago_" : ["fa %n mes","fa %n mesos"],
    "last year" : "l'any passat",
    "_%n hour ago_::_%n hours ago_" : ["fa %n hora","fa %n hores"],
    "_%n minute ago_::_%n minutes ago_" : ["fa %n minut","fa %n minuts"],
    "seconds ago" : "segons enrere",
    "None" : "Cap",
    "Username" : "Nom d'usuari",
    "Password" : "Contrasenya",
    "File name contains at least one invalid character" : "El nom del fitxer conté al menys un caràcter invàlid",
    "App directory already exists" : "La carpeta de l'aplicació ja existeix",
    "Can't create app folder. Please fix permissions. %s" : "No es pot crear la carpeta de l'aplicació. Arregleu els permisos. %s",
    "No source specified when installing app" : "No heu especificat la font en instal·lar l'aplicació",
    "No href specified when installing app from http" : "No heu especificat href en instal·lar l'aplicació des de http",
    "No path specified when installing app from local file" : "No heu seleccionat el camí en instal·lar una aplicació des d'un fitxer local",
    "Archives of type %s are not supported" : "Els fitxers del tipus %s no són compatibles",
    "Failed to open archive when installing app" : "Ha fallat l'obertura del fitxer en instal·lar l'aplicació",
    "App does not provide an info.xml file" : "L'aplicació no proporciona un fitxer info.xml",
    "App can't be installed because of not allowed code in the App" : "L'aplicació no es pot instal·lar perquè hi ha codi no autoritzat en l'aplicació",
    "App can't be installed because it is not compatible with this version of ownCloud" : "L'aplicació no es pot instal·lar perquè no és compatible amb aquesta versió d'ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'aplicació no es pot instal·lar perquè conté l'etiqueta <shipped>vertader</shipped> que no es permet per aplicacions no enviades",
    "Apps" : "Aplicacions",
    "General" : "General",
    "Storage" : "Emmagatzemament",
    "Security" : "Seguretat",
    "Encryption" : "Xifrat",
    "Sharing" : "Compartir",
    "Search" : "Cerca",
    "Updates" : "Actualitzacions",
    "%s enter the database username." : "%s escriviu el nom d'usuari de la base de dades.",
    "%s enter the database name." : "%s escriviu el nom de la base de dades.",
    "%s you may not use dots in the database name" : "%s no podeu usar punts en el nom de la base de dades",
    "Oracle connection could not be established" : "No s'ha pogut establir la connexió Oracle",
    "Oracle username and/or password not valid" : "Nom d'usuari i/o contrasenya Oracle no vàlids",
    "DB Error: \"%s\"" : "Error DB: \"%s\"",
    "Offending command was: \"%s\"" : "L'ordre en conflicte és: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Heu d'escriure un compte existent o el d'administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "L'ordre en conflicte és: \"%s\", nom: %s, contrasenya: %s",
    "PostgreSQL username and/or password not valid" : "Nom d'usuari i/o contrasenya PostgreSQL no vàlids",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X no té suport i %s no funcionarà correctament en aquesta plataforma. Useu-ho al vostre risc!",
    "For the best results, please consider using a GNU/Linux server instead." : "Per millors resultats, millor considereu utilitzar un servidor GNU/Linux.",
    "Set an admin username." : "Establiu un nom d'usuari per l'administrador.",
    "Set an admin password." : "Establiu una contrasenya per l'administrador.",
    "Invalid Federated Cloud ID" : "ID de núvol federat invàlid",
    "%s shared »%s« with you" : "%s ha compartit »%s« amb tu",
    "Sharing %s failed, because the file does not exist" : "Ha fallat en compartir %s, perquè el fitxer no existeix",
    "You are not allowed to share %s" : "No se us permet compartir %s",
    "Sharing %s failed, because the user %s does not exist" : "Ha fallat en compartir %s, perquè l'usuari %s no existeix",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Ha fallat en compartir %s, perquè l'usuari %s no és membre de cap grup dels que %s és membre",
    "Sharing %s failed, because this item is already shared with %s" : "Ha fallat en compartir %s, perquè l'element ja està compartit amb %s",
    "Sharing %s failed, because the group %s does not exist" : "Ha fallat en compartir %s, perquè el grup %s no existeix",
    "Sharing %s failed, because %s is not a member of the group %s" : "Ha fallat en compartir %s, perquè %s no és membre del grup %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Heu de proporcionar una contrasenya per crear un enllaç públic. Només es permeten enllaços segurs.",
    "Sharing %s failed, because sharing with links is not allowed" : "Ha fallat en compartir %s, perquè no es permet compartir amb enllaços",
    "Not allowed to create a federated share with the same user" : "No està permés crear una compartició federada amb el mateix usuari",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "La compartició de %s ha fallat, no es pot trobar %s, potser el servidor està actualment innacessible.",
    "Share type %s is not valid for %s" : "La compartició tipus %s no és vàlida per %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Ha fallat en establir els permisos per %s perquè aquests excedeixen els permesos per a %s",
    "Setting permissions for %s failed, because the item was not found" : "Ha fallat en establir els permisos per %s, perquè no s'ha trobat l'element",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "No es pot guardar la data d'expiració. Els fitxers o carpetes compartits no poden expirar més tard de %s després d'haver-se compratit.",
    "Cannot set expiration date. Expiration date is in the past" : "No es pot guardar la data d'expiració. La data d'expiració ja ha passat.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El rerefons de compartició %s ha d'implementar la interfície OCP\\Share_Backend",
    "Sharing backend %s not found" : "El rerefons de compartició %s no s'ha trobat",
    "Sharing backend for %s not found" : "El rerefons de compartició per a %s no s'ha trobat",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Ha fallat en compartir %s perquè els permisos excedeixen els permesos per a %s",
    "Sharing %s failed, because resharing is not allowed" : "Ha fallat en compartir %s, perquè no es permet compartir de nou",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Ha fallat en compartir %s, perquè el rerefons de compartir per %s no pot trobar la seva font",
    "Sharing %s failed, because the file could not be found in the file cache" : "Ha fallat en compartir %s, perquè el fitxer no s'ha trobat en el fitxer cau",
    "Could not find category \"%s\"" : "No s'ha trobat la categoria \"%s\"",
    "A valid username must be provided" : "Heu de facilitar un nom d'usuari vàlid",
    "A valid password must be provided" : "Heu de facilitar una contrasenya vàlida",
    "The username is already being used" : "El nom d'usuari ja està en ús",
    "Help" : "Ajuda",
    "Settings" : "Configuració",
    "Users" : "Usuaris",
    "web services under your control" : "controleu els vostres serveis web",
    "Application is not enabled" : "L'aplicació no està habilitada",
    "Authentication error" : "Error d'autenticació",
    "Token expired. Please reload page." : "El testimoni ha expirat. Torneu a carregar la pàgina.",
    "Unknown user" : "Usuari desconegut",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No hi ha instal·lats controladors de bases de dades (sqlite, mysql o postgresql).",
    "Cannot write into \"config\" directory" : "No es pot escriure a la carpeta \"config\"",
    "Cannot write into \"apps\" directory" : "No es pot escriure a la carpeta \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Això normalment es pot solucionar donant a %s permís d'escriptura a la carpeta d'aplicacions %s o inhabilitant la botiga d'aplicacions en el fitxer de configuració.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Això normalment es pot solucionar donant a %s permís d'escriptura a la carpeta de configuració %s",
    "Setting locale to %s failed" : "Ha fallat en establir la llengua a %s",
    "Please install one of these locales on your system and restart your webserver." : "Siusplau, instal·li un d'aquests arxius de localització en el seu sistema, i reinicii el seu servidor web.",
    "Please ask your server administrator to install the module." : "Demaneu a l'administrador del sistema que instal·li el mòdul.",
    "PHP module %s not installed." : "El mòdul PHP %s no està instal·lat.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Això probablement està provocat per una cau/accelerador com Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "S'han instal·lat mòduls PHP, però encara es llisten com una mancança?",
    "Please ask your server administrator to restart the web server." : "Demaneu a l'administrador que reinici el servidor web.",
    "PostgreSQL >= 9 required" : "Es requereix PostgreSQL >= 9",
    "Please upgrade your database version" : "Actualitzeu la versió de la base de dades",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Canvieu els permisos a 0770 per tal que la carpeta no es pugui llistar per altres usuaris.",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Comproveu que la carpeta de dades contingui un fitxer \".ocdata\" a la seva arrel.",
    "Could not obtain lock type %d on \"%s\"." : "No s'ha pogut obtenir un bloqueig tipus %d a \"%s\"."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/ca.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "No es pot escriure a la carpeta \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Això normalment es pot solucionar donant al servidor web permís d'escriptura a la carpeta de configuració",
    "See %s" : "Comproveu %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Això normalment es pot solucionar donant a %s permís d'escriptura a la carpeta de configuració %s",
    "Sample configuration detected" : "Configuració d'exemple detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S'ha detectat que la configuració d'exemple ha estat copiada. Això no està suportat, i podria corrompre la vostra instalació. Siusplau, llegiu la documentació abans de realitzar canvis a config.php",
    "PHP %s or higher is required." : "Es requereix PHP %s o superior.",
    "Unknown filetype" : "Tipus de fitxer desconegut",
    "Invalid image" : "Imatge no vàlida",
    "today" : "avui",
    "yesterday" : "ahir",
    "last month" : "el mes passat",
    "_%n month ago_::_%n months ago_" : ["fa %n mes","fa %n mesos"],
    "last year" : "l'any passat",
    "_%n hour ago_::_%n hours ago_" : ["fa %n hora","fa %n hores"],
    "_%n minute ago_::_%n minutes ago_" : ["fa %n minut","fa %n minuts"],
    "seconds ago" : "segons enrere",
    "None" : "Cap",
    "Username" : "Nom d'usuari",
    "Password" : "Contrasenya",
    "File name contains at least one invalid character" : "El nom del fitxer conté al menys un caràcter invàlid",
    "App directory already exists" : "La carpeta de l'aplicació ja existeix",
    "Can't create app folder. Please fix permissions. %s" : "No es pot crear la carpeta de l'aplicació. Arregleu els permisos. %s",
    "No source specified when installing app" : "No heu especificat la font en instal·lar l'aplicació",
    "No href specified when installing app from http" : "No heu especificat href en instal·lar l'aplicació des de http",
    "No path specified when installing app from local file" : "No heu seleccionat el camí en instal·lar una aplicació des d'un fitxer local",
    "Archives of type %s are not supported" : "Els fitxers del tipus %s no són compatibles",
    "Failed to open archive when installing app" : "Ha fallat l'obertura del fitxer en instal·lar l'aplicació",
    "App does not provide an info.xml file" : "L'aplicació no proporciona un fitxer info.xml",
    "App can't be installed because of not allowed code in the App" : "L'aplicació no es pot instal·lar perquè hi ha codi no autoritzat en l'aplicació",
    "App can't be installed because it is not compatible with this version of ownCloud" : "L'aplicació no es pot instal·lar perquè no és compatible amb aquesta versió d'ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'aplicació no es pot instal·lar perquè conté l'etiqueta <shipped>vertader</shipped> que no es permet per aplicacions no enviades",
    "Apps" : "Aplicacions",
    "General" : "General",
    "Storage" : "Emmagatzemament",
    "Security" : "Seguretat",
    "Encryption" : "Xifrat",
    "Sharing" : "Compartir",
    "Search" : "Cerca",
    "Updates" : "Actualitzacions",
    "%s enter the database username." : "%s escriviu el nom d'usuari de la base de dades.",
    "%s enter the database name." : "%s escriviu el nom de la base de dades.",
    "%s you may not use dots in the database name" : "%s no podeu usar punts en el nom de la base de dades",
    "Oracle connection could not be established" : "No s'ha pogut establir la connexió Oracle",
    "Oracle username and/or password not valid" : "Nom d'usuari i/o contrasenya Oracle no vàlids",
    "DB Error: \"%s\"" : "Error DB: \"%s\"",
    "Offending command was: \"%s\"" : "L'ordre en conflicte és: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Heu d'escriure un compte existent o el d'administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "L'ordre en conflicte és: \"%s\", nom: %s, contrasenya: %s",
    "PostgreSQL username and/or password not valid" : "Nom d'usuari i/o contrasenya PostgreSQL no vàlids",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X no té suport i %s no funcionarà correctament en aquesta plataforma. Useu-ho al vostre risc!",
    "For the best results, please consider using a GNU/Linux server instead." : "Per millors resultats, millor considereu utilitzar un servidor GNU/Linux.",
    "Set an admin username." : "Establiu un nom d'usuari per l'administrador.",
    "Set an admin password." : "Establiu una contrasenya per l'administrador.",
    "Invalid Federated Cloud ID" : "ID de núvol federat invàlid",
    "%s shared »%s« with you" : "%s ha compartit »%s« amb tu",
    "Sharing %s failed, because the file does not exist" : "Ha fallat en compartir %s, perquè el fitxer no existeix",
    "You are not allowed to share %s" : "No se us permet compartir %s",
    "Sharing %s failed, because the user %s does not exist" : "Ha fallat en compartir %s, perquè l'usuari %s no existeix",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Ha fallat en compartir %s, perquè l'usuari %s no és membre de cap grup dels que %s és membre",
    "Sharing %s failed, because this item is already shared with %s" : "Ha fallat en compartir %s, perquè l'element ja està compartit amb %s",
    "Sharing %s failed, because the group %s does not exist" : "Ha fallat en compartir %s, perquè el grup %s no existeix",
    "Sharing %s failed, because %s is not a member of the group %s" : "Ha fallat en compartir %s, perquè %s no és membre del grup %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Heu de proporcionar una contrasenya per crear un enllaç públic. Només es permeten enllaços segurs.",
    "Sharing %s failed, because sharing with links is not allowed" : "Ha fallat en compartir %s, perquè no es permet compartir amb enllaços",
    "Not allowed to create a federated share with the same user" : "No està permés crear una compartició federada amb el mateix usuari",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "La compartició de %s ha fallat, no es pot trobar %s, potser el servidor està actualment innacessible.",
    "Share type %s is not valid for %s" : "La compartició tipus %s no és vàlida per %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Ha fallat en establir els permisos per %s perquè aquests excedeixen els permesos per a %s",
    "Setting permissions for %s failed, because the item was not found" : "Ha fallat en establir els permisos per %s, perquè no s'ha trobat l'element",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "No es pot guardar la data d'expiració. Els fitxers o carpetes compartits no poden expirar més tard de %s després d'haver-se compratit.",
    "Cannot set expiration date. Expiration date is in the past" : "No es pot guardar la data d'expiració. La data d'expiració ja ha passat.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El rerefons de compartició %s ha d'implementar la interfície OCP\\Share_Backend",
    "Sharing backend %s not found" : "El rerefons de compartició %s no s'ha trobat",
    "Sharing backend for %s not found" : "El rerefons de compartició per a %s no s'ha trobat",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Ha fallat en compartir %s perquè els permisos excedeixen els permesos per a %s",
    "Sharing %s failed, because resharing is not allowed" : "Ha fallat en compartir %s, perquè no es permet compartir de nou",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Ha fallat en compartir %s, perquè el rerefons de compartir per %s no pot trobar la seva font",
    "Sharing %s failed, because the file could not be found in the file cache" : "Ha fallat en compartir %s, perquè el fitxer no s'ha trobat en el fitxer cau",
    "Could not find category \"%s\"" : "No s'ha trobat la categoria \"%s\"",
    "A valid username must be provided" : "Heu de facilitar un nom d'usuari vàlid",
    "A valid password must be provided" : "Heu de facilitar una contrasenya vàlida",
    "The username is already being used" : "El nom d'usuari ja està en ús",
    "Help" : "Ajuda",
    "Settings" : "Configuració",
    "Users" : "Usuaris",
    "web services under your control" : "controleu els vostres serveis web",
    "Application is not enabled" : "L'aplicació no està habilitada",
    "Authentication error" : "Error d'autenticació",
    "Token expired. Please reload page." : "El testimoni ha expirat. Torneu a carregar la pàgina.",
    "Unknown user" : "Usuari desconegut",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No hi ha instal·lats controladors de bases de dades (sqlite, mysql o postgresql).",
    "Cannot write into \"config\" directory" : "No es pot escriure a la carpeta \"config\"",
    "Cannot write into \"apps\" directory" : "No es pot escriure a la carpeta \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Això normalment es pot solucionar donant a %s permís d'escriptura a la carpeta d'aplicacions %s o inhabilitant la botiga d'aplicacions en el fitxer de configuració.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Això normalment es pot solucionar donant a %s permís d'escriptura a la carpeta de configuració %s",
    "Setting locale to %s failed" : "Ha fallat en establir la llengua a %s",
    "Please install one of these locales on your system and restart your webserver." : "Siusplau, instal·li un d'aquests arxius de localització en el seu sistema, i reinicii el seu servidor web.",
    "Please ask your server administrator to install the module." : "Demaneu a l'administrador del sistema que instal·li el mòdul.",
    "PHP module %s not installed." : "El mòdul PHP %s no està instal·lat.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Això probablement està provocat per una cau/accelerador com Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "S'han instal·lat mòduls PHP, però encara es llisten com una mancança?",
    "Please ask your server administrator to restart the web server." : "Demaneu a l'administrador que reinici el servidor web.",
    "PostgreSQL >= 9 required" : "Es requereix PostgreSQL >= 9",
    "Please upgrade your database version" : "Actualitzeu la versió de la base de dades",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Canvieu els permisos a 0770 per tal que la carpeta no es pugui llistar per altres usuaris.",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Comproveu que la carpeta de dades contingui un fitxer \".ocdata\" a la seva arrel.",
    "Could not obtain lock type %d on \"%s\"." : "No s'ha pogut obtenir un bloqueig tipus %d a \"%s\".",
    "A safe home for all your data" : "Una llar segura per a les seves dades",
    "Storage is temporarily not available" : "Emmagatzemament temporalment no disponible",
    "Imprint" : "Imprint",
    "__language_name__" : "Català"
},
"nplurals=2; plural=(n != 1);");
